<?php 

if (!class_exists('OAK_Post_Types')) {

	class OAK_Post_Types {
	
		var $cp;
		
		var $taxonomy_name;
		var $taxonomy_labels;
	
		function __construct($args) {
			$this->cp = (object)$args;
			$this->init_post_type();
		}
		
		function init_post_type() {			
			if (!isset($this->cp->name)) $this->cp->name = 'Article';
			if (!isset($this->cp->plurralname)) $this->cp->plurralname = $this->cp->name . 's';
			if (!isset($this->cp->label)) $this->cp->label = $this->cp->plurralname;
			if (!isset($this->cp->hierarchical)) $this->cp->hierarchical = false;
			if (!isset($this->cp->slug)) $this->cp->slug = preg_replace('/[^a-zA-Z0-9\s]/', '', strtolower($this->cp->label));
			if (!isset($this->cp->full_slug)) $this->cp->full_slug = '_' . $this->cp->slug;
			if (!isset($this->cp->supported)) $this->cp->supported = array('title', 'editor', 'thumbnail', 'comments', 'excerpt');
			if (!isset($this->cp->menu_position)) $this->cp->menu_position = 50;

			//$posttypes[] = $this->cp->full_slug;
			
			add_action( 'init', array(&$this, 'build_posttype') );
			
			add_action( 'admin_head', array(&$this, 'cpt_icons') );
		}
		
		function build_posttype() {
			register_post_type(
				$this -> cp -> full_slug,
				array(
				  	'labels' => array(
					    'name' => $this->cp->label,
						'singular_name' => $this->cp->name,
						'add_new' => 'Add New',
						'all_items' => 'All '.$this->cp->plurralname,
						'add_new_item' => 'Add New '.$this->cp->name,
						'edit_item' => 'Edit '.$this->cp->name,
						'new_item' => 'Add New',
						'view_item' => 'View '.$this->cp->name,
						'search_item' => 'Search '.$this->cp->plurralname,
						'not_found' => 'No '.$this->cp->plurralname.' Found',
						'not_found_in_trash' => 'No '.$this->cp->plurralname.' found in trash'
					),
					'description' => (isset($this->cp->description) ? $this->cp->description : null),
					'rewrite' => array(
						'slug' => $this->cp->slug
					),
					'supports' => $this->cp->supported,
					'public' => true,
					'has_archive' => true,
					'hierarchical' => $this->cp->hierarchical,
					'menu_position' => $this->cp->menu_position,
					'show_in_nav_menus' => false
				)
			);
		}
		
		function add_custom_taxonomy($name, $plurral_name, $hierarchical = false, $usecpname = false, $slug = null) {
			$labels = array(
			    'name' => (($usecpname === true) ? $this->cp->name.' ' : null) . $plurral_name,
			    'singular_name' => (($usecpname === true) ? $this->cp->name.' ' : null) . $name,
			    'search_items' => (($usecpname === true) ? $this->cp->name.' ' : null) . $plurral_name,
			    'all_items' => 'All '.(($usecpname === true) ? $this->cp->name.' ' : null) . $plurral_name,
			    'parent_item' => 'Parent '.(($usecpname === true) ? $this->cp->name.' ' : null) . $name,
			    'parent_item_colon' => 'Parent '.(($usecpname === true) ? $this->cp->name.' ' : null) . $name.':',
			    'edit_item' => 'Edit '.(($usecpname === true) ? $this->cp->name.' ' : null) . $name, 
			    'update_item' => 'Update '.(($usecpname === true) ? $this->cp->name.' ' : null) . $name,
			    'add_new_item' => 'Add New '.(($usecpname === true) ? $this->cp->name.' ' : null) . $name,
			    'new_item_name' => 'New '.(($usecpname === true) ? $this->cp->name.' ' : null) . $name.' Name'
			);
			
			if ($slug == null)
				$slug = strtolower(urlencode(str_replace(" ", "-", $name)));
			$taxonomy_name = $this->cp->full_slug.'_'.$slug;
			$taxonomy_labels = array(
			    'labels' => $labels,
			    'hierarchical' => $hierarchical,
				'rewrite' => array('slug' => $this->cp->slug.'/'.strtolower(urlencode(str_replace(" ", "-", $name)))),
				'show_in_nav_menus' => false
			);
		
			register_taxonomy($taxonomy_name, $this->cp->full_slug, $taxonomy_labels);
		}
		
		function cpt_icons() {
			if (file_exists(get_stylesheet_directory() . '/icons/' . $this->cp->full_slug . '.png' )) { ?>
			<style type="text/css" media="screen">
			   	#adminmenu #menu-posts-<?php echo $this->cp->full_slug; ?> .wp-menu-image {
			        background: url('<?php echo get_stylesheet_directory_uri(); ?>/icons/<?php echo $this->cp->full_slug; ?>.png') no-repeat 6px -18px !important;
			    }
				#adminmenu #menu-posts-<?php echo $this->cp->full_slug; ?>:hover .wp-menu-image, #menu-posts-<?php echo $this->cp->full_slug; ?>.wp-has-current-submenu .wp-menu-image {
			        background: url('<?php echo get_stylesheet_directory_uri(); ?>/icons/<?php echo $this->cp->full_slug; ?>.png') no-repeat 6px 6px !important;
			    }
			</style>
		<?php }
		}
		
	}	
}
?>