<?php 
if (get_locale() == 'fr_FR') {
	add_action('wp_enqueue_scripts', 'add_french_dates');

	function add_french_dates() {		
		wp_enqueue_script('french_dates', '/wp-content/themes/francais/includes/datepicker-fr.js');
	}
}

function page_includes() {
	wp_enqueue_script('date-picker', '/wp-content/plugins/oak-events/includes/datepicker.min.js');
	wp_enqueue_script('eventcalendar', '/wp-content/plugins/oak-events/includes/eventcalendar.js');
	wp_enqueue_style('date_picker', '/wp-content/plugins/oak-events/includes/ui-smoothness/jquery-ui-1.8.16.custom.css');
	wp_enqueue_style('calendar-style', '/wp-content/plugins/oak-events/includes/style.css');
}

add_action('wp_enqueue_scripts', 'page_includes');

if ($_SERVER['REQUEST_METHOD'] == 'POST' && !empty( $_POST['action'])) {
	
	$error = null;
	
	if (isset ($_POST['title']) && $_POST['title'] != null) $title = esc_attr($_POST['title']); 
	else $error .= __('Please enter the name of the event', 'p2p').'<br/>';
	
	if (isset ($_POST['description']) && $_POST['description'] != null) $description = esc_attr($_POST['description']); 
	else $error .= __('Please enter the event description', 'p2p').'<br/>';

	if (isset ($_POST['location']) && $_POST['location'] != null) $location = esc_attr($_POST['location']); 
	else $error .= __('Please enter an event location', 'p2p').'<br/>';
	
	if (isset ($_POST['address']) && $_POST['address'] != null) $address = esc_attr($_POST['address']); 
	else $error .= __('Please enter the address of the event', 'p2p').'<br/>';
	
	if (isset ($_POST['startdate']) && $_POST['startdate'] != null) $startdate = esc_attr($_POST['startdate']); 
	else $error .= __('Please enter the start date', 'p2p').'<br/>';
	
	if (isset ($_POST['enddate']) && $_POST['enddate'] != null) $enddate = esc_attr($_POST['enddate']); 
	else $error .= __('Please enter the end date', 'p2p').'<br/>';
	
	if (isset ($_POST['starttime']) && $_POST['starttime'] != null) $starttime = esc_attr($_POST['starttime']); 
	else $error .= __('Please enter the start time', 'p2p').'<br/>';
	
	if (isset ($_POST['endtime']) && $_POST['endtime'] != null) $endtime = esc_attr($_POST['endtime']); 
	else $error .= __('Please enter the end time', 'p2p').'<br/>';

	if (isset ($_POST['website'])) $website = esc_attr($_POST['website']); 
	if (isset ($_POST['price'])) $price = esc_attr($_POST['price']); 
	if (isset ($_POST['event_hotel_link'])) $event_hotel_link = esc_attr($_POST['event_hotel_link']); 
	if (isset ($_POST['event_eventbrite'])) $event_eventbrite = esc_attr($_POST['event_eventbrite']); 
	if (isset ($_POST['event_contact'])) $event_contact = esc_attr($_POST['event_contact']); 

	$existing = get_page_by_title($title, false, '_events');
	if (!empty($existing)) {
		$error .= __('There is already an event with this title, please choose a unique title', 'p2p').'<br/>';
	}

	if ($error == null && empty($existing)) {				
		$newpost->post_title = $title;
		$newpost->post_content = $description;
		$newpost->post_status = 'pending';	
		$newpost->post_type = '_events';
		$newpost->post_author = 3;

		national_blog_id();
		$post_id = wp_insert_post($newpost);

		add_post_meta($post_id, '_event_date_date_0', strtotime($startdate));
		add_post_meta($post_id, '_event_date_starttime_0', $starttime);	

		if ($startdate != $enddate) {
			add_post_meta($post_id, '_event_date_date_1', strtotime($enddate));	
			add_post_meta($post_id, '_event_date_endtime_1', $endtime);
		} else 
			add_post_meta($post_id, '_event_date_endtime_0', $endtime);
		add_post_meta($post_id, '_event_location', $location);
		add_post_meta($post_id, '_event_street_address', $address);
	
		if ($website != null) 
			add_post_meta($post_id, '_event_website', $website);
		if ($price != null) 
			add_post_meta($post_id, '_event_price', $price);
		if ($event_hotel_link != null) 
			add_post_meta($post_id, '_event_hotel_link', $event_hotel_link);
		if ($event_contact != null) 
			add_post_meta($post_id, '_event_contact', $event_contact);

		add_filter( 'wp_mail_content_type', 'set_html_content_type' );
		wp_mail('communications@p2pcanada.ca', get_option('blogname').' Event Submission', "A new event entitled '".$title."' has been submitted into moderation from the 'Suggest an Event' form.\nPlease login to publish or remove this event:<br/><br/>Approve Event: <a href='http://p2pcanada.ca/wp-admin/edit.php?post_type=_events'>http://p2pcanada.ca/wp-admin/edit.php?post_type=_events</a>"); 
		remove_filter( 'wp_mail_content_type', 'set_html_content_type' ); 

		$success = true;
	} else {
		$success = false;
	}
	
}

function set_html_content_type(){
	return 'text/html';
}

get_header(); 

	get_sidebar(); ?>
		
	<div class="content wide event">

		<div>
			<ul class="breadcrumbs">
				<li><a href="/"><?php _e('Home', 'p2p'); ?></a></li>
				<li><a href="/events/"><?php _e('Events', 'p2p'); ?></a></li>
				<li><a href="/suggest-event/"><?php _e('Suggest an Event', 'p2p'); ?></a></li>
			</ul>
			<div class="search right">
				<?php get_template_part('search'); ?>
			</div>
		</div>
		
		<article id="post-<?php the_ID(); ?>">

			<?php 
			wp_reset_query();
			national_blog_events();
			if (have_posts()) : 
				while (have_posts()) : 
					the_post(); ?>

					<h2><?php the_title(); ?></h2>
							
					<section>
						<?php the_content(); ?>
					</section>

					<hr/>

			<?php endwhile; 
			endif; ?>
			
			<?php if (isset($success) && $success == true) : ?>
			<div class="success">
				<?php _e('Thank you for your event submission, it has been added to our moderation queue.', 'p2p'); ?>
			</div>
			<?php elseif (isset($error) && $error != null) : ?>
			<div class="success red">
				<?php echo $error; ?>
			</div>
			<?php endif; ?>
			
			
			<form id="suggest" name="suggest" method="post" action="">
				<p class="half">
					<label for="title"><?php _e('Event Name', 'p2p'); ?> <span class="red">*</span></label>
					<input type="text" id="title" tabindex="1" size="20" name="title" value="<?php echo (isset($title)) ? $title : null; ?>" />
				</p>
				<p class="half end">
					<label for="website"><?php _e('Event Website', 'p2p'); ?></label>
					<input type="text" id="website" tabindex="1" size="20" name="website" value="<?php echo (isset($website)) ? $website : null; ?>" />
				</p>
				<div id="suggestbox">
					<p>
						<label for="startdate"><?php _e('Start Date', 'p2p'); ?> <span class="red">*</span></label>
						<span class="inputcontain">
							<input type="text" id="startdate" class="calendar" value="<?php echo (isset($startdate)) ? $startdate : null; ?>" tabindex="1" size="20" name="startdate" />
						</span> <?php _e('at', 'p2p'); ?> 
						<select name="starttime">
							<?php if (isset($startdate) && $startdate != null) : ?>
							<option><?php echo $starttime; ?></option>
							<?php endif; ?>
							<option>12:00 AM</option>
							<option>1:00 AM</option>
							<option>2:00 AM</option>
							<option>3:00 AM</option>
							<option>4:00 AM</option>
							<option>5:00 AM</option>
							<option>6:00 AM</option>
							<option>7:00 AM</option>
							<option>8:00 AM</option>
							<option>9:00 AM</option>
							<option>10:00 AM</option>
							<option>11:00 AM</option>
							<option>12:00 PM</option>
							<option>1:00 PM</option>
							<option>2:00 PM</option>
							<option>3:00 PM</option>
							<option>4:00 PM</option>
							<option>5:00 PM</option>
							<option>6:00 PM</option>
							<option>7:00 PM</option>
							<option>8:00 PM</option>
							<option>9:00 PM</option>
							<option>10:00 PM</option>
							<option>11:00 PM</option>
						</select>
					</p>
					<p>
						<label for="enddate"><?php _e('End Date', 'p2p'); ?> <span class="red">*</span></label>
						<span class="inputcontain">
							<input type="text" id="enddate" class="calendar" value="<?php echo (isset($enddate)) ? $enddate : null; ?>" tabindex="1" size="20" name="enddate" />
						</span> <?php _e('at', 'p2p'); ?>
						<select name="endtime">
							<?php if (isset($endtime) && $endtime != null) : ?>
							<option><?php echo $endtime; ?></option>
							<?php endif; ?>
							<option>12:00 AM</option>
							<option>1:00 AM</option>
							<option>2:00 AM</option>
							<option>3:00 AM</option>
							<option>4:00 AM</option>
							<option>5:00 AM</option>
							<option>6:00 AM</option>
							<option>7:00 AM</option>
							<option>8:00 AM</option>
							<option>9:00 AM</option>
							<option>10:00 AM</option>
							<option>11:00 AM</option>
							<option>12:00 PM</option>
							<option>1:00 PM</option>
							<option>2:00 PM</option>
							<option>3:00 PM</option>
							<option>4:00 PM</option>
							<option>5:00 PM</option>
							<option>6:00 PM</option>
							<option>7:00 PM</option>
							<option>8:00 PM</option>
							<option>9:00 PM</option>
							<option>10:00 PM</option>
							<option>11:00 PM</option>
						</select>
					</p>
				</div>
				<p class="half">
					<label for="location"><?php _e('Location Name', 'p2p'); ?> <span class="red">*</span></label>
					<input type="text" id="location" value="<?php echo (isset($location)) ? $location : null; ?>" tabindex="1" size="20" name="location" />
				</p>
				<p class="half end">
					<label for="address"><?php _e('Location Street Address', 'p2p'); ?> <span class="red">*</span></label>
					<input type="text" id="address" value="<?php echo (isset($address)) ? $address : null; ?>" tabindex="1" size="20" name="address" />
				</p>
				<p class="half">
					<label for="price"><?php _e('Price', 'p2p'); ?></label>
					<input type="text" id="price" value="<?php echo (isset($price)) ? $price : null; ?>" tabindex="1" size="20" name="price" />
				</p>
				<p class="half end">
					<label for="event_hotel_link"><?php _e('Hotel URL', 'p2p'); ?></label>
					<input type="text" id="event_hotel_link" value="<?php echo (isset($event_hotel_link)) ? $event_hotel_link : null; ?>" tabindex="1" size="20" name="event_hotel_link" />
				</p>
				<p class="half">
					<label for="event_contact"><?php _e('Contact Information', 'p2p'); ?></label>
					<input type="text" id="event_contact" value="<?php echo (isset($event_contact)) ? $event_contact : null; ?>" tabindex="1" size="20" name="event_contact" />
				</p>
				<p class="description">
					<label for="description"><?php _e('Event Description', 'p2p'); ?> <span class="red">*</span></label>
					<textarea id="description" tabindex="3" name="description" cols="50" rows="6"><?php echo (isset($description)) ? $description : null; ?></textarea>
				</p>
				
				<p align="left"><input type="submit" value="<?php _e('Submit', 'p2p'); ?>" class="button" tabindex="6" id="submit" name="submit" /></p>
				
				<?php global $post; ?>
				<input type="hidden" name="page" id="page" value="< ? php echo $post->ID; ? >"/>			
				<input type="hidden" name="action" value="post" />
				<?php wp_nonce_field( 'new-post' ); ?>
			</form>

		</article>
	
	</div>

<?php get_footer(); ?>
